@@ -214,6 +214,10 @@ async def sync_preseem_model(preseem_model,
                 if bpkg:
                     if not isinstance(bpkg.name, str) or bpkg.name == '':
                         raise ValueError('invalid string value for package name')
+                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int) or bpkg.download_rate < 0):
+                        raise ValueError('invalid value for package down rate')
+                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int) or bpkg.upload_rate < 0):
+                        raise ValueError('invalid value for package up rate')
                     changes = []
                     mods = {}
                     new_package_ids.discard(mpkg.source_id)
@@ -223,12 +227,12 @@ async def sync_preseem_model(preseem_model,
                     if mpkg.name != bpkg.name:
                         changes.append(f'name: {mpkg.name} -> {bpkg.name}')
                         mods['name'] = bpkg.name
-                    if mpkg.download_rate != bpkg.download_rate:
+                    if mpkg.download_rate != (bpkg.download_rate or None):
                         changes.append(f'download_rate: {mpkg.download_rate} -> {bpkg.download_rate}')
-                        mods['download_rate'] = bpkg.download_rate
-                    if mpkg.upload_rate != bpkg.upload_rate:
+                        mods['download_rate'] = bpkg.download_rate or None
+                    if mpkg.upload_rate != (bpkg.upload_rate or None):
                         changes.append(f'upload_rate: {mpkg.upload_rate} -> {bpkg.upload_rate}')
-                        mods['upload_rate'] = bpkg.upload_rate
+                        mods['upload_rate'] = bpkg.upload_rate or None
                     if mods:
                         logging.info('sync_packages(%s): modify %s (%s)',
                                      source, mpkg, ', '.join(changes))
@@ -253,6 +257,10 @@ async def sync_preseem_model(preseem_model,
                         raise ValueError('invalid string value for package source_id')
                     if not isinstance(bpkg.name, str) or bpkg.name == '':
                         raise ValueError('invalid string value for package name')
+                    if bpkg.download_rate and (not isinstance(bpkg.download_rate, int) or bpkg.download_rate < 0):
+                        raise ValueError('invalid value for package down rate')
+                    if bpkg.upload_rate and (not isinstance(bpkg.upload_rate, int) or bpkg.upload_rate < 0):
+                        raise ValueError('invalid value for package up rate')
                     logging.info('sync_preseem_model(%s): create %s', source, bpkg)
                     if not noact:
                         mpkg = await call_and_log_error(
@@ -261,8 +269,8 @@ async def sync_preseem_model(preseem_model,
                                 name=bpkg.name,
                                 source=source,
                                 source_id=bpkg.id,
-                                download_rate=bpkg.download_rate,
-                                upload_rate=bpkg.upload_rate))
+                                download_rate=bpkg.download_rate or None,
+                                upload_rate=bpkg.upload_rate or None))
                         if mpkg:
                             uuid = UUID(bytes=mpkg.uuid)
                             logging.info(
